@@ -26,13 +26,16 @@
 
 pkg.initGettext();
 pkg.initFormat();
-pkg.require({ 'Gdk': '3.0',
-              'Gio': '2.0',
-              'GLib': '2.0',
-              'GObject': '2.0',
-              'Gtk': '3.0' });
+pkg.require({ 
+    'Gdk': '3.0',
+    'Gio': '2.0',
+    'GLib': '2.0',
+    'GObject': '2.0',
+    'Gtk': '3.0',
+    'Handy': '1',
+});
 
-const {GLib, Gio, GObject, Gtk} = imports.gi;
+const {GLib, Gio, GObject, Gtk, Handy} = imports.gi;
 
 const Util = imports.util;
 const Window = imports.window;
@@ -52,7 +55,7 @@ var MyApplication = GObject.registerClass({
         super._init({ application_id: application_id,
                       flags: Gio.ApplicationFlags.FLAGS_NONE });
 
-        GLib.set_application_name(_('Characters Application'));
+        GLib.set_application_name(_('Characters'));
     }
 
     _onQuit () {
@@ -68,6 +71,9 @@ var MyApplication = GObject.registerClass({
     vfunc_startup () {
         super.vfunc_startup();
 
+        let theme = Gtk.IconTheme.get_default();
+        theme.add_resource_path('/org/gnome/Characters/icons');
+
         Util.loadStyleSheet('/org/gnome/Characters/application.css');
 
         Util.initActions(this,
@@ -77,24 +83,28 @@ var MyApplication = GObject.registerClass({
                             activate: this._onSearch,
                             parameter_type: new GLib.VariantType('as') }]);
         this.set_accels_for_action('app.quit', ['<Primary>q']);
+        this.set_accels_for_action('win.find', ['<Primary>f']);
+        this.set_accels_for_action('win.show-primary-menu', ['F10']);
+        this.set_accels_for_action('win.show-help-overlay', ['<Primary>question']);
 
         settings = Util.getSettings('org.gnome.Characters',
                                     '/org/gnome/Characters/');
 
-        log(_("Characters Application started"));
+        log("Characters Application started");
     }
 
     vfunc_activate() {
         if (!this._appwindow) {
             this._appwindow = new Window.MainWindow({ application: this });
         }
+        Handy.init();
 
         this._appwindow.present();
-        log(_("Characters Application activate"));
+        log("Characters Application activated");
     }
 
     vfunc_shutdown() {
-        log(_("Characters Application exiting"));
+        log("Characters Application exiting");
 
         super.vfunc_shutdown();
     }
