@@ -19,6 +19,7 @@
 
 const {Gc, Gdk, Gio, GLib, GObject} = imports.gi;
 
+const ByteArray = imports.byteArray;
 const Service = imports.service;
 const Util = imports.util;
 
@@ -48,7 +49,7 @@ var SearchProvider = GObject.registerClass({
         this._cancellable.cancel();
         this._cancellable.reset();
 
-        let upper = keywords.map(String.prototype.toUpperCase);
+        let upper = keywords.map(x => x.toUpperCase());
         let criteria = Gc.SearchCriteria.new_keywords(upper);
         let context = new Gc.SearchContext({ criteria: criteria,
                                              flags: Gc.SearchFlag.WORD });
@@ -154,4 +155,4 @@ var SearchProvider = GObject.registerClass({
         this._activateAction('search', new GLib.Variant('as', terms),
                              timestamp);
     }
-});
\ No newline at end of file
+});
